from setuptools import setup

setup(
    name='example_python_package_Blitan',
    author='Keir',
    author_email='keirhearn@gmail.com',
    license='MIT',
    url='https://github.com/Blitan/example_python_package_Blitan',
    description='XXX Skeleton python project example.',
    packages=["example_python_package_Blitan"],
    version="0.0.2"
)




from example_python_package_Blitan import my_name

def test_long_name():

    answer = my_name('averylongname')

    assert answer == "my name is averylongname"

def test_short_name():

    answer = my_name('name')

    assert answer == "my name is name"